from setuptools import setup, find_packages

setup(
    name='nltpk',
    version='2.0',
    packages=find_packages(),
    include_package_data=True,
    description='Saver',
    author='Your Name',
)
